<template>
  <section
    v-show="SoftwareStudio.shop_color && SoftwareStudio.shop_style"
    :class="{ ['color' + SoftwareStudio.shop_color]: true, ['layout' + SoftwareStudio.shop_style]: true }"
    class="software-studio">
    <div class="shop-html">
      <div class="shop-body">
        <div class="headerwidthcontainer">
          <div id="topnavbar">
            <div
              v-if="SoftwareStudio.admin"
              id="menu">
              <ul
                id="nav"
                class="tab-buttons">
                <router-link
                  :to="{name: 'software_studiomain'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'software_studiomain')}"
                    class="tab">Home
                  </a>
                </router-link>
                <router-link
                  :to="{name: 'software_studioaccounting'}"
                  tag="li">
                  <a
                    :class="{selected: (this.$route.name === 'software_studioaccounting')}"
                    class="tab">Accounting</a>
                </router-link>
                <div class="clear"/>
              </ul>
            </div>
          </div>
          <div id="yatlogo">
            <img
              id="yatlogoimg"
              :src="logo"
              width="98"
              height="81">
          </div>
          <div class="banner">
            <div id="shopname">{{ SoftwareStudio.name }}</div>
            <div id="tagline">
              <p v-if="SoftwareStudio.shop_style === 1">{ {{ SoftwareStudio.description }} }</p>
              <p v-else>{{ SoftwareStudio.description }}</p>
            </div>
            <div class="banner-image" />
          </div>
        </div>
        <div class="clear"/>
        <div class="contentwidthcontainer">
          <div class="thecontent">
            <div id="sidebar">
              <headlines />
              <div class="action-buttons-header" />
              <action-buttons
                v-if="Object.keys(SoftwareStudio).length"
                :has-swiper="hasSwiper"
                :shop="SoftwareStudio"/>
            </div>
              <router-view
                :shop="SoftwareStudio"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo" />

          </div>
          <div class="clear"/>
        </div>

      </div>
    </div>
  </section>
</template>

<script>
import ShopBaseView from "../shopBase.js";
import Headlines from "../Headlines.vue";
import ActionButtons from "../ActionButtons.vue";

export default {
  components: {
    Headlines,
    ActionButtons,
  },
  extends: ShopBaseView,
  data() {
    return {
      logo: app.network.data.shop_logo,
      SoftwareStudio: {},
      hasSwiper: app.computerSettings.swiper,
    };
  },
  created: function () {
    this.getData();
  },
  beforeMount: function () {
    this.$router.push({name: "software_studiomain"});
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "software_studio/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.SoftwareStudio = Response;
            app.Message( "Successfully loaded the Software Studio!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) );
        });
    },
    simpleOne() {
      this.SoftwareStudio.shop_style = 1;
      this.SoftwareStudio.shop_color = 1;
    },
    simpleTwo() {
      this.SoftwareStudio.shop_style = 1;
      this.SoftwareStudio.shop_color = 2;
    },
    busyOne() {
      this.SoftwareStudio.shop_style = 2;
      this.SoftwareStudio.shop_color = 1;
    },
    busyTwo() {
      this.SoftwareStudio.shop_style = 2;
      this.SoftwareStudio.shop_color = 2;
    },
  },

};
</script>

<style lang="less">
.software-studio.layout1.color1 {
  /* Software Studio common */
  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #393947;
  @topnavcolor: #FFF571;
  @shoptitlecolor: #01c2d7;
  @logoborder: 0.5rem solid black;
  @shopdesccolor:#eb6b44;
  @homemsgcolor:#144a68;
  @navbgcolor: #FFF571;
  @tabfontcolor: #21212d;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#01c2d7;
  @buttonborder:#FFF;
  @buttonhoverbg:#eb6b44;
  @buttonp: #fff;
  @buttonborderhover: white;
  @factsbg:#fff;
  @factsh2:#000;
  @factstitlebg:#01c2d7;
  @factslistcolor:#FFF;
  @factscolor: black;
  @actionbuttonheader: #eb6b44;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @softwareimage: url(/images/shop/softwarestudio/L1C1.png);


  @import '../../shared.less';
  @import './softwareStudioLayout1.less';
}

</style>

<style lang="less">
.software-studio.layout1.color2 {
  /* Software Studio common */

  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #6e74af;
  @topnavcolor: #9FF9E4;
  @shoptitlecolor: #ff6978;
  @logoborder: 0.5rem solid black;
  @shopdesccolor:#7b4b94;
  @homemsgcolor:#7f0000;
  @navbgcolor: #9FF9E4;
  @tabfontcolor: #21212d;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#fff;
  @buttonbackground:#ff6978;
  @buttonborder:#FFF;
  @buttonborderhover:#FFF;
  @buttonhoverbg:#505691;
  @buttonp: #fff;
  @factsbg:#fff;
  @factstitlebg:#ff6978;
  @factsh2:#fff;
  @factslistcolor:#ffff;
  @factscolor:#204045;
  @actionbuttonheader: #505691;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @softwareimage: url(/images/shop/softwarestudio/L1C2.png);

  @import '../../shared.less';
  @import './softwareStudioLayout1.less';
  }
  </style>

  <style lang="less">
  .software-studio.layout2.color1 {
  /* Software Studio common */

  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color1
  @bgcolor: #012641;
  @maincontentbg: rgba(163, 212, 245, 1);
  @topnavcolor: #000203;
  @shoptitlecolor: White;
  @logoborder: 0.5rem solid #c7195e;
  @shopdesccolor:#FFF;
  @homemsgcolor:#144a68;
  @navbgcolor: #000203;
  @tabfontcolor: white;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor:#c7195e;
  @buttonbackground:#c7195e;
  @buttonborder:#fff;
  @buttonhoverbg:#03a0fd;
  @buttonborderhover: white;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factsh2:#FFF;
  @factstitlebg: #c7195e;
  @factslistcolor:#ffff;
  @factscolor:#163B53;
  @hometxtcolor:#008e18;
  @shopbackgroundcolor:#fccb42;
  @actionbuttonheader: #03a0fd;
  @softwareimage: url(/images/shop/softwarestudio/L2C1.jpg);
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;

  @import '../../shared.less';
  @import './softwareStudioLayout2.less';
}
</style>

<style lang="less">
.software-studio.layout2.color2 {
  /* Software Studio common */

  @sidebarcolor: rgba(255,255,255,0.82);
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @contentborder: 1px solid #ecf4f8;
  @maincontentcolor: #131736;

  //color2
  @bgcolor: #4f6367;
  @maincontentbg: rgba(249, 222, 174, 1);
  @topnavcolor: white;
  @shoptitlecolor: #01df22;
  @logoborder: 0.5rem solid black;
  @shopdesccolor: black;
  @homemsgcolor:#020101;
  @navbgcolor: white;
  @tabfontcolor: black;
  @maincontentp:#21212d;
  @maincontenth1:#21212d;
  @h1shadow:none;
  @activetabcolor: #678d8e;
  @buttonbackground:#678d8e;
  @buttonborder:#FFF;
  @buttonborderhover:#FFFF;
  @buttonhoverbg:#7a9e9f;
  @buttonp: #fff;
  @factsbg:#FFF;
  @factstitlebg: #678d8e;
  @factsh2:#FFF;
  @factslistcolor:#fff;
  @factscolor:black;
  @hometxtcolor:#337399;
  @shopbackgroundcolor:#2e55b0;
  @actionbuttonheader: #7a9e9f;
  @accountingbackground: rgba(255,255,255,0.93);
  @accountingtextcolor: black;
  @softwareimage: url(/images/shop/softwarestudio/L2C2.jpg);

  @import '../../shared.less';
  @import './softwareStudioLayout2.less';
}

</style>
